@@ -1,7 +1,12 @@
+suppressWarnings(RNGversion("3.5.2"))
+
 ## load package and fix seed
 library("partykit")
 set.seed(1)
 
+if (!require("TH.data"))
+    quit()
+
 ## rpart: kyphosis data
 library("rpart")
 data("kyphosis", package = "rpart")
@@ -115,6 +120,7 @@ nodeprune(ct, "B")
 nodeprune(ct, "C")
 nodeprune(ct, "A")
 
+options(digits = 3)
 ### check different predict flavours for numeric responses
 x <- runif(100)
 dd <- data.frame(y = rnorm(length(x), mean = 2 * (x < .5)), x = x)
